@@ -1,8 +1,7 @@
 package App::Prove::State::Result::Test;
 
 use strict;
-
-use vars qw($VERSION);
+use warnings;
 
 =head1 NAME
 
@@ -10,11 +9,11 @@ App::Prove::State::Result::Test - Individual test results.
 
 =head1 VERSION
 
-Version 3.27
+Version 3.29
 
 =cut
 
-$VERSION = '3.27';
+our $VERSION = '3.29';
 
 =head1 DESCRIPTION
 
