@@ -1,9 +1,8 @@
 package TAP::Parser;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
-use TAP::Base                              ();
 use TAP::Parser::Grammar                   ();
 use TAP::Parser::Result                    ();
 use TAP::Parser::ResultFactory             ();
@@ -18,17 +17,21 @@ use TAP::Parser::SourceHandler::Handle     ();
 
 use Carp qw( confess );
 
+use parent 'TAP::Base';
+
+=encoding utf8
+
 =head1 NAME
 
 TAP::Parser - Parse L<TAP|Test::Harness::TAP> output
 
 =head1 VERSION
 
-Version 3.27
+Version 3.29
 
 =cut
 
-$VERSION = '3.27';
+our $VERSION = '3.29';
 
 my $DEFAULT_TAP_VERSION = 12;
 my $MAX_TAP_VERSION     = 13;
@@ -42,8 +45,6 @@ END {
 }
 
 BEGIN {    # making accessors
-    @ISA = qw(TAP::Base);
-
     __PACKAGE__->mk_methods(
         qw(
           _iterator
@@ -174,7 +175,7 @@ I<NEW to 3.18>.
 
 If set, C<sources> must be a hashref containing the names of the
 L<TAP::Parser::SourceHandler>s to load and/or configure.  The values are a
-hash of configuration that will be accessible to to the source handlers via
+hash of configuration that will be accessible to the source handlers via
 L<TAP::Parser::Source/config_for>.
 
 For example:
@@ -638,7 +639,7 @@ C<$result> object.
 
 Returns a list of pragmas each of which is a + or - followed by the
 pragma name.
- 
+
 =head2 C<comment> methods
 
  if ( $result->is_comment ) { ... }
@@ -1764,7 +1765,7 @@ so without sub-classing C<TAP::Parser> by setting L</iterator_factory_class>.
 If you just need to customize the objects on creation, subclass L<TAP::Parser>
 and override L</make_iterator_factory>.
 
-Note that L</make_source> & L</make_perl_source> have been I<DEPRECATED> and
+Note that C<make_source> & C<make_perl_source> have been I<DEPRECATED> and
 are now removed.
 
 =head3 Iterators
