@@ -1,13 +1,12 @@
 package TAP::Parser::Iterator::Process;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
-use TAP::Parser::Iterator ();
 use Config;
 use IO::Handle;
 
-@ISA = 'TAP::Parser::Iterator';
+use parent 'TAP::Parser::Iterator';
 
 my $IS_WIN32 = ( $^O =~ /^(MS)?Win32$/ );
 
@@ -17,11 +16,11 @@ TAP::Parser::Iterator::Process - Iterator for process-based TAP sources
 
 =head1 VERSION
 
-Version 3.27
+Version 3.29
 
 =cut
 
-$VERSION = '3.27';
+our $VERSION = '3.29';
 
 =head1 SYNOPSIS
 
@@ -79,7 +78,7 @@ Get the exit status for this iterator's process.
 
 {
 
-    local $^W;    # no warnings
+    no warnings 'uninitialized';
        # get around a catch22 in the test suite that causes failures on Win32:
     local $SIG{__DIE__} = undef;
     eval { require POSIX; &POSIX::WEXITSTATUS(0) };
@@ -138,7 +137,7 @@ sub _initialize {
 
         # HOTPATCH {{{
         my $xclose = \&IPC::Open3::xclose;
-        local $^W;    # no warnings
+        no warnings;
         local *IPC::Open3::xclose = sub {
             my $fh = shift;
             no strict 'refs';
