@@ -1,7 +1,7 @@
 package TAP::Parser::Scheduler::Spinner;
 
 use strict;
-use vars qw($VERSION);
+use warnings;
 use Carp;
 
 =head1 NAME
@@ -10,11 +10,11 @@ TAP::Parser::Scheduler::Spinner - A no-op job.
 
 =head1 VERSION
 
-Version 3.27
+Version 3.29
 
 =cut
 
-$VERSION = '3.27';
+our $VERSION = '3.29';
 
 =head1 SYNOPSIS
 
