@@ -1,13 +1,12 @@
 package TAP::Parser::SourceHandler::Executable;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
-use TAP::Parser::SourceHandler     ();
 use TAP::Parser::IteratorFactory   ();
 use TAP::Parser::Iterator::Process ();
 
-@ISA = qw(TAP::Parser::SourceHandler);
+use parent 'TAP::Parser::SourceHandler';
 
 TAP::Parser::IteratorFactory->register_handler(__PACKAGE__);
 
@@ -17,11 +16,11 @@ TAP::Parser::SourceHandler::Executable - Stream output from an executable TAP so
 
 =head1 VERSION
 
-Version 3.27
+Version 3.29
 
 =cut
 
-$VERSION = '3.27';
+our $VERSION = '3.29';
 
 =head1 SYNOPSIS
 
@@ -156,12 +155,11 @@ Please see L<TAP::Parser/SUBCLASSING> for a subclassing overview.
   package MyRubySourceHandler;
 
   use strict;
-  use vars '@ISA';
 
   use Carp qw( croak );
   use TAP::Parser::SourceHandler::Executable;
 
-  @ISA = qw( TAP::Parser::SourceHandler::Executable );
+  use parent 'TAP::Parser::SourceHandler::Executable';
 
   # expect $handler->(['mytest.rb', 'cmdline', 'args']);
   sub make_iterator {
